@@ -4,24 +4,21 @@
  */
 import { getDiForUnitTesting } from "../../renderer/getDiForUnitTesting";
 import { routeSpecificComponentInjectionToken } from "../../renderer/routes/route-specific-component-injection-token";
-import { routeInjectionToken } from "./route-injection-token";
+import { frontEndRouteInjectionToken } from "./front-end-route-injection-token";
 import { filter, map, matches } from "lodash/fp";
 import clusterStoreInjectable from "../cluster-store/cluster-store.injectable";
 import type { ClusterStore } from "../cluster-store/cluster-store";
 import { pipeline } from "@ogre-tools/fp";
 
 describe("verify-that-all-routes-have-component", () => {
-  it("verify that routes have route component", async () => {
+  it("verify that routes have route component", () => {
     const rendererDi = getDiForUnitTesting({ doGeneralOverrides: true });
 
-    rendererDi.override(
-      clusterStoreInjectable,
-      () => ({ getById: (): null => null } as unknown as ClusterStore),
-    );
+    rendererDi.override(clusterStoreInjectable, () => ({
+      getById: () => null,
+    } as unknown as ClusterStore));
 
-    await rendererDi.runSetups();
-
-    const routes = rendererDi.injectMany(routeInjectionToken);
+    const routes = rendererDi.injectMany(frontEndRouteInjectionToken);
     const routeComponents = rendererDi.injectMany(
       routeSpecificComponentInjectionToken,
     );
