@@ -3,12 +3,14 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { appSemVer } from "../../../common/vars";
+import appSemanticVersionInjectable from "../../../common/vars/app-semantic-version.injectable";
 import { isCompatibleExtension } from "./is-compatible-extension";
 
 const isCompatibleExtensionInjectable = getInjectable({
   id: "is-compatible-extension",
-  instantiate: () => isCompatibleExtension({ appSemVer }),
+  instantiate: (di) => isCompatibleExtension({
+    appSemVer: di.inject(appSemanticVersionInjectable),
+  }),
 });
 
 export default isCompatibleExtensionInjectable;
