@@ -8,7 +8,9 @@ import { render } from "@testing-library/react";
 import { SecretDetails } from "../secret-details";
 import { Secret, SecretType } from "../../../../common/k8s-api/endpoints";
 
-jest.mock("../../kube-object-meta/kube-object-meta");
+jest.mock("../../kube-object-meta/kube-object-meta", () => ({
+  KubeObjectMeta: () => null,
+}));
 
 
 describe("SecretDetails tests", () => {
@@ -20,6 +22,8 @@ describe("SecretDetails tests", () => {
         name: "test",
         resourceVersion: "1",
         uid: "uid",
+        namespace: "default",
+        selfLink: "/api/v1/secrets/default/test",
       },
       data: {
         foobar: "",
