@@ -4,12 +4,12 @@
  */
 
 import { observer } from "mobx-react";
-import { now } from "mobx-utils";
 import React from "react";
 import { formatDuration } from "../../utils";
+import { reactiveNow } from "../../../common/utils/reactive-now/reactive-now";
 
 export interface ReactiveDurationProps {
-  timestamp: string;
+  timestamp: string | undefined;
 
   /**
    * Whether the display string should prefer length over precision
@@ -34,11 +34,15 @@ function computeUpdateInterval(creationTimestampEpoch: number): number {
 }
 
 export const ReactiveDuration = observer(({ timestamp, compact = true }: ReactiveDurationProps) => {
-  const creationTimestamp = new Date(timestamp).getTime();
+  if (!timestamp) {
+    return <>{"<unknown>"}</>;
+  }
+
+  const timestampSeconds = new Date(timestamp).getTime();
 
   return (
     <>
-      {formatDuration(now(computeUpdateInterval(creationTimestamp)) - creationTimestamp, compact)}
+      {formatDuration(reactiveNow(computeUpdateInterval(timestampSeconds)) - timestampSeconds, compact)}
     </>
   );
 });
