@@ -64,21 +64,22 @@ export class Tooltip extends React.Component<TooltipProps> {
     autoBind(this);
   }
 
-  get targetElem(): HTMLElement {
+  get targetElem(): HTMLElement | null {
     return document.getElementById(this.props.targetId);
   }
 
-  get hoverTarget(): HTMLElement {
+  get hoverTarget(): HTMLElement | null {
     if (this.props.tooltipOnParentHover) {
-      return this.targetElem.parentElement;
+      return this.targetElem?.parentElement ?? null;
     }
 
     return this.targetElem;
   }
 
   componentDidMount() {
-    this.hoverTarget.addEventListener("mouseenter", this.onEnterTarget);
-    this.hoverTarget.addEventListener("mouseleave", this.onLeaveTarget);
+    this.hoverTarget?.addEventListener("mouseenter", this.onEnterTarget);
+    this.hoverTarget?.addEventListener("mouseleave", this.onLeaveTarget);
+    this.refreshPosition();
   }
 
   componentDidUpdate() {
@@ -86,8 +87,8 @@ export class Tooltip extends React.Component<TooltipProps> {
   }
 
   componentWillUnmount() {
-    this.hoverTarget.removeEventListener("mouseenter", this.onEnterTarget);
-    this.hoverTarget.removeEventListener("mouseleave", this.onLeaveTarget);
+    this.hoverTarget?.removeEventListener("mouseenter", this.onEnterTarget);
+    this.hoverTarget?.removeEventListener("mouseleave", this.onLeaveTarget);
   }
 
   @action
@@ -106,11 +107,12 @@ export class Tooltip extends React.Component<TooltipProps> {
     const { preferredPositions } = this.props;
     const { elem, targetElem } = this;
 
-    if (!elem) {
+    if (!elem || !targetElem) {
       return;
     }
 
-    let positions = new Set<TooltipPosition>([
+    const positions = new Set<TooltipPosition>([
+      ...[preferredPositions ?? []].flat(),
       TooltipPosition.RIGHT,
       TooltipPosition.BOTTOM,
       TooltipPosition.TOP,
@@ -121,15 +123,8 @@ export class Tooltip extends React.Component<TooltipProps> {
       TooltipPosition.BOTTOM_LEFT,
     ]);
 
-    if (preferredPositions) {
-      positions = new Set([
-        ...[preferredPositions].flat(),
-        ...positions,
-      ]);
-    }
-
     // reset position first and get all possible client-rect area for tooltip element
-    this.setPosition({ left: 0, top: 0 });
+    this.setPosition(elem, { left: 0, top: 0 });
 
     const selfBounds = elem.getBoundingClientRect();
     const targetBounds = targetElem.getBoundingClientRect();
@@ -142,7 +137,7 @@ export class Tooltip extends React.Component<TooltipProps> {
 
       if (fitsToWindow) {
         this.activePosition = pos;
-        this.setPosition({ top, left });
+        this.setPosition(elem, { top, left });
 
         return;
       }
@@ -153,24 +148,19 @@ export class Tooltip extends React.Component<TooltipProps> {
     const { left, top } = this.getPosition(fallbackPosition, selfBounds, targetBounds);
 
     this.activePosition = fallbackPosition;
-    this.setPosition({ left, top });
+    this.setPosition(elem, { left, top });
   }
 
-  protected setPosition(pos: { left: number; top: number }) {
-    if (!this.elem) {
-      return;
-    }
-
-    const elemStyle = this.elem.style;
-
-    elemStyle.left = `${pos.left}px`;
-    elemStyle.top = `${pos.top}px`;
+  protected setPosition(elem: HTMLDivElement, pos: { left: number; top: number }) {
+    elem.style.left = `${pos.left}px`;
+    elem.style.top = `${pos.top}px`;
   }
 
   protected getPosition(position: TooltipPosition, tooltipBounds: DOMRect, targetBounds: DOMRect) {
     let left: number;
     let top: number;
-    const offset = this.props.offset;
+    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
+    const offset = this.props.offset!;
     const horizontalCenter = targetBounds.left + (targetBounds.width - tooltipBounds.width) / 2;
     const verticalCenter = targetBounds.top + (targetBounds.height - tooltipBounds.height) / 2;
     const topCenter = targetBounds.top - tooltipBounds.height - offset;
@@ -209,6 +199,8 @@ export class Tooltip extends React.Component<TooltipProps> {
         top = bottomCenter;
         left = targetBounds.right - tooltipBounds.width;
         break;
+      default:
+        throw new TypeError("Invalid props.postition value");
     }
 
     return {
@@ -219,10 +211,6 @@ export class Tooltip extends React.Component<TooltipProps> {
     };
   }
 
-  bindRef(elem: HTMLDivElement) {
-    this.elem = elem;
-  }
-
   render() {
     const { style, formatters, usePortal, children, visible = this.isVisible } = this.props;
 
@@ -235,7 +223,12 @@ export class Tooltip extends React.Component<TooltipProps> {
       formatter: !!formatters,
     });
     const tooltip = (
-      <div className={className} style={style} ref={this.bindRef} role="tooltip">
+      <div
+        className={className}
+        style={style}
+        ref={elem => this.elem = elem}
+        role="tooltip"
+      >
         {children}
       </div>
     );
