@@ -3,11 +3,11 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectionToken } from "@ogre-tools/injectable";
-import type { Route } from "../../common/front-end-routing/route-injection-token";
+import type { Route } from "../../common/front-end-routing/front-end-route-injection-token";
 
 export const routeSpecificComponentInjectionToken = getInjectionToken<{
   route: Route<unknown>;
-  Component: React.ElementType;
+  Component: React.ElementType<any>;
 }>({
   id: "route-specific-component-injection-token",
 });
